# IoTeX ETL

[![Build Status](https://travis-ci.org/blockchain-etl/iotex-etl.png)](https://travis-ci.org/blockchain-etl/iotex-etl)

Example actions:
- Execution: https://iotexscan.io/action/87dc614c88d8f02d0f6f92532ea9c8c4d1aab02ce65cb5db15159251ca5aeda5
- Transfer: https://iotexscan.io/action/28271edf75e641f8ddd5794fc4f775206054ba75b30289822a62d2e0abb45ed0
